@@ -13,7 +13,13 @@ select
 
 set icu_ext.locale to 'en@calendar=ethiopic';
 set icu_ext.date_format to '{short}';
-set icu_ext.timestamptz_format to '{short}';
+
+-- Use an explicit format for icu_timestamptz instead of {short},
+-- since {short} had varied across ICU versions:
+-- before ICU v72, the separator between hour and AM/PM designator
+-- is an ASCII space, whereas since v72 it is NARROW NO-BREAK SPACE (U+202F)
+--set icu_ext.timestamptz_format to '{short}';
+set icu_ext.timestamptz_format to 'M/d/y G, hh:mm a';
 
 -- 13-month year with 5 days in the last month
 select '1/13/2016 ERA1'::icu_date + icu_interval '12 months' as d1,
